Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'core/WidgetsList.php')
-rw-r--r--core/WidgetsList.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/WidgetsList.php b/core/WidgetsList.php
index 83a3fdc8e2..01ac7f5178 100644
--- a/core/WidgetsList.php
+++ b/core/WidgetsList.php
@@ -31,7 +31,7 @@ class WidgetsList
/**
* Returns all available widgets
* The event WidgetsList.addWidget is used to create the list
*
* @return array
*/
@@ -56,7 +56,7 @@ class WidgetsList
{
if (!self::$hookCalled) {
self::$hookCalled = true;
- Piwik_PostEvent('WidgetsList.addWidget');
+ Piwik_PostEvent('WidgetsList.addWidgets');
}
}
@@ -31,7 +31,7 @@ class WidgetsList
/**
* Returns all available widgets
- * The event WidgetsList.addWidget is used to create the list
+ * The event WidgetsList.addWidgets is used to create the list
*
* @return array